# Generated by Django 5.2.7 on 2026-01-22 17:31

import netbox.models.deletion
import taggit.managers
import utilities.json
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("extras", "0133_make_cf_minmax_decimal"),
        ("netbox_snmp", "0002_userprofiles"),
    ]

    operations = [
        migrations.CreateModel(
            name="ViewTrees",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True, null=True)),
                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
                ("custom_field_data", models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder)),
                ("name", models.CharField(max_length=100)),
                ("description", models.CharField(blank=True, max_length=100)),
                ("comments", models.TextField(blank=True)),
                ("view_type", models.CharField(default="included")),
                ("oid", models.CharField(max_length=32)),
                ("tags", taggit.managers.TaggableManager(through="extras.TaggedItem", to="extras.Tag")),
            ],
            options={
                "verbose_name_plural": "Views",
                "ordering": ["name"],
            },
            bases=(netbox.models.deletion.DeleteMixin, models.Model),
        ),
    ]



from rest_framework.serializers import HyperlinkedIdentityField
from netbox.api.serializers import NetBoxModelSerializer

from ..models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles


# region TRAP PROFILES
class TrapProfilesSerializer(NetBoxModelSerializer):
    url = HyperlinkedIdentityField(view_name="plugins-api:netbox_snmp-api:trapprofiles-detail")

    class Meta:
        model = TrapProfiles
        fields = ["id", "url", "display", "name", "version", "level", "target", "port", "timeout", "retries", "description", "tags", "custom_fields", "comments", "user_profile"]
        brief_fields = ("id", "url", "display", "name", "version", "level", "user_profile", "target")


# endregion


# region USER PROFILES
class UserProfilesSerializer(NetBoxModelSerializer):
    url = HyperlinkedIdentityField(view_name="plugins-api:netbox_snmp-api:userprofiles-detail")

    class Meta:
        model = UserProfiles
        fields = ["id", "url", "display", "name", "priv", "auth", "description", "tags", "custom_fields", "comments"]
        brief_fields = ("id", "url", "display", "name", "priv", "auth")


# endregion


# region MIB TREES
class MIBTreesSerializer(NetBoxModelSerializer):
    url = HyperlinkedIdentityField(view_name="plugins-api:netbox_snmp-api:mibtrees-detail")

    class Meta:
        model = MIBTrees
        fields = ["id", "url", "display", "name", "oid", "view_type", "description", "tags", "custom_fields", "comments"]
        brief_fields = ("id", "url", "display", "name", "oid", "view_type")


# endregion


# region NOTIFY TREES
class NotifyProfilesSerializer(NetBoxModelSerializer):
    url = HyperlinkedIdentityField(view_name="plugins-api:netbox_snmp-api:notifyprofiles-detail")

    class Meta:
        model = NotifyProfiles
        fields = ["id", "url", "display", "name", "notification_type", "description", "tags", "custom_fields", "comments"]
        brief_fields = ("id", "url", "display", "name", "notification_type")


# endregion



from django.db.models import Q
from netbox.filtersets import NetBoxModelFilterSet
from utilities.filtersets import register_filterset

# from utilities.filtersets import register_filterset
from .models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles


# region TRAP PROFILES
@register_filterset
class TrapProfilesFilterSet(NetBoxModelFilterSet):
    class Meta:
        model = TrapProfiles
        fields = [
            "id",
            "name",
            "version",
            "level",
            "target",
        ]

    def search(self, queryset, name, value):
        if not value.strip():
            return queryset

        qs_filter = Q(name__icontains=value) | Q(description__icontains=value) | Q(target__icontains=value)
        return queryset.filter(qs_filter)


# endregion


# region USER PROFILES
@register_filterset
class UserProfilesFilterSet(NetBoxModelFilterSet):
    class Meta:
        model = UserProfiles
        fields = [
            "id",
            "name",
            "auth",
            "priv",
        ]

    def search(self, queryset, name, value):
        if not value.strip():
            return queryset

        qs_filter = Q(name__icontains=value) | Q(description__icontains=value) | Q(target__icontains=value)
        return queryset.filter(qs_filter)


# endregion


# region MIB TREES
@register_filterset
class MIBTreesFilterSet(NetBoxModelFilterSet):
    class Meta:
        model = MIBTrees
        fields = [
            "id",
            "name",
            "view_type",
        ]

    def search(self, queryset, name, value):
        if not value.strip():
            return queryset

        return queryset.filter(Q(name__icontains=value) | Q(description__icontains=value) | Q(target__icontains=value) | Q(oid__contains=[value]))


# endregion


# region NOTIFY
@register_filterset
class NotifyProfilesFilterSet(NetBoxModelFilterSet):
    class Meta:
        model = NotifyProfiles
        fields = ["name", "notification_type"]

    def search(self, queryset, name, value):
        if not value.strip():
            return queryset

        qs_filter = Q(name__icontains=value) | Q(description__icontains=value) | Q(target__icontains=value)
        return queryset.filter(qs_filter)


# endregion



from netbox.views import generic
from . import forms, tables, filtersets
from utilities.views import register_model_view
from .models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles


# region TRAP PROFILE
@register_model_view(TrapProfiles)
class TrapProfilesView(generic.ObjectView):
    queryset = TrapProfiles.objects.all()
    template_name = "netbox_snmp/trapprofiles.html"


@register_model_view(TrapProfiles, "list", path="", detail=False)
class TrapProfilesListView(generic.ObjectListView):
    queryset = TrapProfiles.objects.all()
    filterset = filtersets.TrapProfilesFilterSet
    filterset_form = forms.TrapProfilesFilterForm
    table = tables.TrapProfilesTable


@register_model_view(TrapProfiles, "add", detail=False)
@register_model_view(TrapProfiles, "edit")
class TrapProfilesEditView(generic.ObjectEditView):
    queryset = TrapProfiles.objects.all()
    form = forms.TrapProfilesForm


@register_model_view(TrapProfiles, "delete")
class TrapProfilesDeleteView(generic.ObjectDeleteView):
    queryset = TrapProfiles.objects.all()
    default_return_url = "plugins:netbox_snmp:trapprofiles_list"


@register_model_view(TrapProfiles, "bulk_delete", detail=False)
class TrapProfilesBulkDeleteView(generic.BulkDeleteView):
    queryset = TrapProfiles.objects.all()
    table = tables.TrapProfilesTable
    default_return_url = "plugins:netbox_snmp:trapprofiles_list"


@register_model_view(TrapProfiles, "bulk_edit", path="edit", detail=False)
class TrapProfilesBulkEditView(generic.BulkEditView):
    queryset = TrapProfiles.objects.all()
    filterset = filtersets.TrapProfilesFilterSet
    table = tables.TrapProfilesTable
    form = forms.TrapProfilesBulkEditForm


# endregion


# region USER PROFILE
@register_model_view(UserProfiles)
class UserProfilesView(generic.ObjectView):
    queryset = UserProfiles.objects.all()
    template_name = "netbox_snmp/userprofiles.html"


@register_model_view(UserProfiles, "list", path="", detail=False)
class UserProfilesListView(generic.ObjectListView):
    queryset = UserProfiles.objects.all()
    filterset = filtersets.UserProfilesFilterSet
    filterset_form = forms.UserProfilesFilterForm
    table = tables.UserProfilesTable


@register_model_view(UserProfiles, "add", detail=False)
@register_model_view(UserProfiles, "edit")
class UserProfilesEditView(generic.ObjectEditView):
    queryset = UserProfiles.objects.all()
    form = forms.UserProfilesForm


@register_model_view(UserProfiles, "delete")
class UserProfilesDeleteView(generic.ObjectDeleteView):
    queryset = UserProfiles.objects.all()
    default_return_url = "plugins:netbox_snmp:userprofiles_list"


@register_model_view(UserProfiles, "bulk_delete", detail=False)
class UserProfilesBulkDeleteView(generic.BulkDeleteView):
    queryset = UserProfiles.objects.all()
    table = tables.UserProfilesTable
    default_return_url = "plugins:netbox_snmp:userprofiles_list"


@register_model_view(UserProfiles, "bulk_edit", path="edit", detail=False)
class UserProfilesBulkEditView(generic.BulkEditView):
    queryset = UserProfiles.objects.all()
    filterset = filtersets.UserProfilesFilterSet
    table = tables.UserProfilesTable
    form = forms.UserProfilesBulkEditForm


# endregion


# region MIB TREES
@register_model_view(MIBTrees)
class MIBTreesView(generic.ObjectView):
    queryset = MIBTrees.objects.all()
    template_name = "netbox_snmp/mibtrees.html"


@register_model_view(MIBTrees, "list", path="", detail=False)
class MIBTreesListView(generic.ObjectListView):
    queryset = MIBTrees.objects.all()
    filterset = filtersets.MIBTreesFilterSet
    filterset_form = forms.MIBTreesFilterForm
    table = tables.MIBTreesTable


@register_model_view(MIBTrees, "add", detail=False)
@register_model_view(MIBTrees, "edit")
class MIBTreesEditView(generic.ObjectEditView):
    queryset = MIBTrees.objects.all()
    form = forms.MIBTreesForm


@register_model_view(MIBTrees, "delete")
class MIBTreesDeleteView(generic.ObjectDeleteView):
    queryset = MIBTrees.objects.all()
    default_return_url = "plugins:netbox_snmp:mibtrees_list"


@register_model_view(MIBTrees, "bulk_delete", detail=False)
class MIBTreesBulkDeleteView(generic.BulkDeleteView):
    queryset = MIBTrees.objects.all()
    table = tables.MIBTreesTable
    default_return_url = "plugins:netbox_snmp:mibtrees_list"


@register_model_view(MIBTrees, "bulk_edit", path="edit", detail=False)
class MIBTreesBulkEditView(generic.BulkEditView):
    queryset = MIBTrees.objects.all()
    filterset = filtersets.MIBTreesFilterSet
    table = tables.MIBTreesTable
    form = forms.MIBTreesBulkEditForm


# endregion


# region NOTIFY
@register_model_view(NotifyProfiles)
class NotifyProfilesView(generic.ObjectView):
    queryset = NotifyProfiles.objects.all()
    template_name = "netbox_snmp/notifyprofiles.html"


@register_model_view(NotifyProfiles, "list", path="", detail=False)
class NotifyProfilesListView(generic.ObjectListView):
    queryset = NotifyProfiles.objects.all()
    filterset = filtersets.NotifyProfilesFilterSet
    filterset_form = forms.NotifyProfilesFilterForm
    table = tables.NotifyProfilesTable


@register_model_view(NotifyProfiles, "add", detail=False)
@register_model_view(NotifyProfiles, "edit")
class NotifyProfilesEditView(generic.ObjectEditView):
    queryset = NotifyProfiles.objects.all()
    form = forms.NotifyProfilesForm


@register_model_view(NotifyProfiles, "delete")
class NotifyProfilesDeleteView(generic.ObjectDeleteView):
    queryset = NotifyProfiles.objects.all()
    default_return_url = "plugins:netbox_snmp:notifyprofiles_list"


@register_model_view(NotifyProfiles, "bulk_delete", detail=False)
class NotifyProfilesBulkDeleteView(generic.BulkDeleteView):
    queryset = NotifyProfiles.objects.all()
    table = tables.NotifyProfilesTable
    default_return_url = "plugins:netbox_snmp:notifyprofiles_list"


@register_model_view(NotifyProfiles, "bulk_edit", path="edit", detail=False)
class NotifyProfilesBulkEditView(generic.BulkEditView):
    queryset = NotifyProfiles.objects.all()
    filterset = filtersets.NotifyProfilesFilterSet
    table = tables.NotifyProfilesTable
    form = forms.NotifyProfilesBulkEditForm


# endregion



# Generated by Django 5.2.7 on 2026-01-22 21:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0006_notifyprofiles"),
    ]

    operations = [
        migrations.RenameField(
            model_name="notifyprofiles",
            old_name="_type",
            new_name="noti_type",
        ),
    ]



# Generated by Django 5.2.7 on 2026-01-22 20:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0004_rename_viewtrees_mibtrees"),
    ]

    operations = [
        migrations.AddField(
            model_name="trapprofiles",
            name="user_profile",
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name="trapprofiles", to="netbox_snmp.userprofiles"),
        ),
    ]



from django.urls import include, path
from utilities.urls import get_model_urls
from . import views
from .models import TrapProfiles, UserProfiles, MIBTrees

app_name = "netbox_snmp"

urlpatterns = (
    # region TRAP PROFILES
    path(
        "traps/",
        include(get_model_urls("netbox_snmp", "trapprofiles", detail=False)),
    ),
    path(
        "traps/<int:pk>/",
        include(get_model_urls("netbox_snmp", "trapprofiles")),
    ),
    # endregion
    # region USER PROFILES
    path(
        "users/",
        include(get_model_urls("netbox_snmp", "userprofiles", detail=False)),
    ),
    path(
        "users/<int:pk>/",
        include(get_model_urls("netbox_snmp", "userprofiles")),
    ),
    # endregion
    # region MIB TREES
    path(
        "view/",
        include(get_model_urls("netbox_snmp", "mibtrees", detail=False)),
    ),
    path(
        "view/<int:pk>/",
        include(get_model_urls("netbox_snmp", "mibtrees")),
    ),
    # endregion
    # region NOTIFY
    path(
        "notify/",
        include(get_model_urls("netbox_snmp", "notifyprofiles", detail=False)),
    ),
    path(
        "notify/<int:pk>/",
        include(get_model_urls("netbox_snmp", "notifyprofiles")),
    ),
    # endregion
)



from django.urls import reverse
from django.contrib.postgres.fields import ArrayField
from netbox.models import NetBoxModel
from django.db import models
from .choices import SNMPUserVersionChoices, SNMPAuthChoices, SNMPPrivChoices, SNMPLevelChoices, SNMPOIDChoices, SNMPNotifyChoices
from django.core.validators import MinValueValidator, MaxValueValidator


class SNMPBase(NetBoxModel):
    name = models.CharField(max_length=100)
    description = models.CharField(max_length=100, blank=True)
    comments = models.TextField(blank=True)

    class Meta:
        abstract = True


# region TRAP PROFILES
class TrapProfiles(SNMPBase):
    version = models.CharField(max_length=32, choices=SNMPUserVersionChoices.CHOICES, default=SNMPUserVersionChoices.V3)
    target = models.GenericIPAddressField()
    port = models.PositiveIntegerField(default=162, validators=[MaxValueValidator(65535)])
    level = models.CharField(max_length=32, choices=SNMPLevelChoices.CHOICES, default=SNMPLevelChoices.AUTH_PRIV)
    timeout = models.PositiveIntegerField(default=15)
    retries = models.PositiveIntegerField(default=3)
    user_profile = models.ForeignKey("UserProfiles", on_delete=models.PROTECT, related_name="trapprofiles", null=True, blank=True)

    def get_absolute_url(self):
        return reverse("plugins:netbox_snmp:trapprofiles", args=[self.pk])

    class Meta:
        verbose_name_plural = "Trap Profiles"
        ordering = ["name"]

    def __str__(self):
        return self.name


# endregion


# region USER PROFILES
class UserProfiles(SNMPBase):
    auth = models.CharField(choices=SNMPAuthChoices.CHOICES, blank=True)
    priv = models.CharField(choices=SNMPPrivChoices.CHOICES, blank=True)

    def get_absolute_url(self):
        return reverse("plugins:netbox_snmp:userprofiles", args=[self.pk])

    class Meta:
        verbose_name_plural = "User Profiles"
        ordering = ["name"]

    def __str__(self):
        return self.name


# endregion


# region MIB TREES
class MIBTrees(SNMPBase):
    view_type = models.CharField(choices=SNMPOIDChoices.CHOICES, default=SNMPOIDChoices.INCLUDED)
    oid = ArrayField(models.CharField(max_length=32), verbose_name="OID(s)", blank=True, default=list)

    def get_absolute_url(self):
        return reverse("plugins:netbox_snmp:mibtrees", args=[self.pk])

    class Meta:
        verbose_name_plural = "MIB Views"
        ordering = ["name"]

    def __str__(self):
        return self.name


# endregion


# region NOTIFY
class NotifyProfiles(SNMPBase):
    notification_type = models.CharField(choices=SNMPNotifyChoices.CHOICES, default=SNMPNotifyChoices.TRAP)

    def get_absolute_url(self):
        return reverse("plugins:netbox_snmp:notifyprofiles", args=[self.pk])

    class Meta:
        verbose_name_plural = "Notify Profiles"
        ordering = ["name"]

    def __str__(self):
        return self.name


# endregion



from netbox.api.routers import NetBoxRouter
from .views import TrapProfilesViewSet, RootView, UserProfilesViewSet, MIBTreesViewSet, NotifyProfilesViewSet

router = NetBoxRouter()
router.APIRootView = RootView
router.register("trapprofiles", TrapProfilesViewSet)
router.register("userprofiles", UserProfilesViewSet)
router.register("mibtrees", MIBTreesViewSet)
router.register("notifyprofiles", NotifyProfilesViewSet)
urlpatterns = router.urls



# Generated by Django 5.2.7 on 2026-01-22 18:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('extras', '0133_make_cf_minmax_decimal'),
        ('netbox_snmp', '0003_viewtrees'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ViewTrees',
            new_name='MibTrees',
        ),
    ]



# Generated by Django 5.2.7 on 2026-01-22 21:20

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0007_rename__type_notifyprofiles_noti_type"),
    ]

    operations = [
        migrations.RenameField(
            model_name="notifyprofiles",
            old_name="noti_type",
            new_name="notification_type",
        ),
    ]



from netbox.tables import NetBoxTable, ChoiceFieldColumn
import django_tables2 as tables
from netbox.tables import NetBoxTable
from .models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles


# region TRAP PROFILES
class TrapProfilesTable(NetBoxTable):
    name = tables.Column(linkify=True)
    user_profile = tables.Column(linkify=True)
    target = tables.Column()

    class Meta(NetBoxTable.Meta):
        model = TrapProfiles
        fields = ("pk", "level", "name", "port", "version", "user_profile", "target")
        default_columns = ("name", "level", "version", "port", "user_profile", "target")


# endregion


# region USER PROFILES
class UserProfilesTable(NetBoxTable):
    name = tables.Column(linkify=True)

    class Meta(NetBoxTable.Meta):
        model = UserProfiles
        fields = ("pk", "level", "name", "auth", "priv")
        default_columns = ("name", "auth", "priv")


# endregion


# region MIB TREES
class MIBTreesTable(NetBoxTable):
    name = tables.Column(linkify=True)

    class Meta(NetBoxTable.Meta):
        model = MIBTrees
        fields = ("pk", "name", "oid", "view_type")
        default_columns = ("name", "oid", "view_type")


# endregion


# region NOTIFY
class NotifyProfilesTable(NetBoxTable):
    name = tables.Column(linkify=True)

    class Meta(NetBoxTable.Meta):
        model = NotifyProfiles
        fields = ("pk", "name", "notification_type")
        default_columns = ("name", "notification_type")


# endregion



from netbox.plugins import PluginConfig


class SNMPConfig(PluginConfig):
    name = "netbox_snmp"
    verbose_name = "SNMP"
    description = "Track SNMP related objects"
    version = "0.4.0"
    author = "AGE Solutions"
    author_email = "michael.terrero@age.solutions"
    base_url = "snmp"
    default_settings = {
        "device_ext_page": "right",
        "top_level_menu": False,
    }


config = SNMPConfig



from setuptools import find_packages, setup

setup(
    name="netbox-snmp",
    version="0.4.0",
    description="SNMP related data",
    author="AGE Solutions",
    author_email="michael.terrero@age.solutions",
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)



from netbox.forms import NetBoxModelForm, NetBoxModelFilterSetForm, NetBoxModelBulkEditForm
from utilities.forms.fields import CommentField, TagFilterField
from .models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles
from django import forms


# region TRAP PROFILES
class TrapProfilesForm(NetBoxModelForm):
    comments = CommentField()

    class Meta:
        model = TrapProfiles
        fields = ["name", "level", "version", "target", "port", "description", "comments", "tags", "user_profile"]


class TrapProfilesFilterForm(NetBoxModelFilterSetForm):
    model = TrapProfiles
    q = forms.CharField(required=False, label="Search")

    tag = TagFilterField(model)


class TrapProfilesBulkEditForm(NetBoxModelBulkEditForm):
    description = forms.CharField(max_length=200, required=False)

    model = TrapProfiles
    nullable_fields = [
        "description",
    ]


# endregion


# region USER PROFILES
class UserProfilesForm(NetBoxModelForm):
    comments = CommentField()

    class Meta:
        model = UserProfiles
        fields = [
            "name",
            "auth",
            "priv",
            "description",
            "comments",
            "tags",
        ]


class UserProfilesFilterForm(NetBoxModelFilterSetForm):
    model = UserProfiles
    q = forms.CharField(required=False, label="Search")

    tag = TagFilterField(model)


class UserProfilesBulkEditForm(NetBoxModelBulkEditForm):
    description = forms.CharField(max_length=200, required=False)

    model = UserProfiles
    nullable_fields = [
        "description",
    ]


# endregion


# region MIB TREES
class MIBTreesForm(NetBoxModelForm):
    comments = CommentField()

    class Meta:
        model = MIBTrees
        fields = [
            "name",
            "oid",
            "view_type",
            "description",
            "comments",
            "tags",
        ]


class MIBTreesFilterForm(NetBoxModelFilterSetForm):
    model = MIBTrees
    q = forms.CharField(required=False, label="Search")

    tag = TagFilterField(model)


class MIBTreesBulkEditForm(NetBoxModelBulkEditForm):
    description = forms.CharField(max_length=200, required=False)

    model = MIBTrees
    nullable_fields = [
        "description",
    ]


# endregion


# region NOTIFY
class NotifyProfilesForm(NetBoxModelForm):
    comments = CommentField()

    class Meta:
        model = NotifyProfiles
        fields = [
            "name",
            "notification_type",
            "description",
            "comments",
            "tags",
        ]


class NotifyProfilesFilterForm(NetBoxModelFilterSetForm):
    model = NotifyProfiles
    q = forms.CharField(required=False, label="Search")

    tag = TagFilterField(model)


class NotifyProfilesBulkEditForm(NetBoxModelBulkEditForm):
    description = forms.CharField(max_length=200, required=False)

    model = NotifyProfiles
    nullable_fields = [
        "description",
    ]


# endregion



# Generated by Django 5.2.7 on 2026-01-22 21:24

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("netbox_snmp", "0008_rename_noti_type_notifyprofiles_notification_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mibtrees",
            name="oid",
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=32), blank=True, default=list, size=None),
        ),
    ]



from netbox.api.viewsets import NetBoxModelViewSet
from ..models import TrapProfiles, UserProfiles, MIBTrees, NotifyProfiles
from .serializers import TrapProfilesSerializer, UserProfilesSerializer, MIBTreesSerializer, NotifyProfilesSerializer
from ..filtersets import TrapProfilesFilterSet, UserProfilesFilterSet, MIBTreesFilterSet, NotifyProfilesFilterSet
from rest_framework.routers import APIRootView


class RootView(APIRootView):
    def get_view_name(self):
        return "SNMP"


# region TRAP PROFILES
class TrapProfilesViewSet(NetBoxModelViewSet):
    queryset = TrapProfiles.objects.all()
    serializer_class = TrapProfilesSerializer
    filterset_class = TrapProfilesFilterSet


# endregion


# region TRAP PROFILES
class UserProfilesViewSet(NetBoxModelViewSet):
    queryset = UserProfiles.objects.all()
    serializer_class = UserProfilesSerializer
    filterset_class = UserProfilesFilterSet


# endregion


# region MIB TREES
class MIBTreesViewSet(NetBoxModelViewSet):
    queryset = MIBTrees.objects.all()
    serializer_class = MIBTreesSerializer
    filterset_class = MIBTreesFilterSet


# endregion


# region NOTIFY TREES
class NotifyProfilesViewSet(NetBoxModelViewSet):
    queryset = NotifyProfiles.objects.all()
    serializer_class = NotifyProfilesSerializer
    filterset_class = NotifyProfilesFilterSet


# endregion



from django.conf import settings
from netbox.plugins import PluginMenuButton, PluginMenuItem, PluginMenu

menu_items = (
    # region TRAP PROFILES
    PluginMenuItem(
        link="plugins:netbox_snmp:trapprofiles_list",
        link_text="Trap Profiles",
        buttons=(
            PluginMenuButton(
                link="plugins:netbox_snmp:trapprofiles_add",
                title="Add",
                icon_class="mdi mdi-plus-thick",
            ),
        ),
    ),
    # endregion
    # region USER PROFILES
    PluginMenuItem(
        link="plugins:netbox_snmp:userprofiles_list",
        link_text="User Profiles",
        buttons=(
            PluginMenuButton(
                link="plugins:netbox_snmp:userprofiles_add",
                title="Add",
                icon_class="mdi mdi-plus-thick",
            ),
        ),
    ),
    # endregion
    # region MIB TREES
    PluginMenuItem(
        link="plugins:netbox_snmp:mibtrees_list",
        link_text="MIB Trees",
        buttons=(
            PluginMenuButton(
                link="plugins:netbox_snmp:mibtrees_add",
                title="Add",
                icon_class="mdi mdi-plus-thick",
            ),
        ),
    ),
    # endregion
    # region NOTIFY
    PluginMenuItem(
        link="plugins:netbox_snmp:notifyprofiles_list",
        link_text="Notify Profiles",
        buttons=(
            PluginMenuButton(
                link="plugins:netbox_snmp:notifyprofiles_add",
                title="Add",
                icon_class="mdi mdi-plus-thick",
            ),
        ),
    ),
    # endregion
)



from utilities.choices import ChoiceSet


class SNMPUserVersionChoices(ChoiceSet):
    V1 = "v1"
    V2C = "v2c"
    V3 = "v3"

    CHOICES = [(V1, "v1"), (V2C, "v2c"), (V3, "v3")]


class SNMPAuthChoices(ChoiceSet):
    SHA = "sha"
    MD5 = "md5"

    CHOICES = [(SHA, "sha"), (MD5, "md5")]


class SNMPPrivChoices(ChoiceSet):
    AES = "aes"
    DES = "des"
    CHOICES = [(AES, "aes"), (DES, "des")]


class SNMPLevelChoices(ChoiceSet):
    AUTH_PRIV = "auth-priv"
    AUTH_NO_PRIV = "auth-no-priv"
    NONE = "no-auth-no-priv"

    CHOICES = [(AUTH_PRIV, "auth-priv"), (AUTH_NO_PRIV, "auth-no-priv"), (NONE, "no-auth-no-priv")]


class SNMPOIDChoices(ChoiceSet):
    INCLUDED = "included"
    EXCLUDED = "excluded"

    CHOICES = [(INCLUDED, "included"), (EXCLUDED, "excluded")]


class SNMPNotifyChoices(ChoiceSet):
    TRAP = "trap"
    NOTIFY = "notify"

    CHOICES = [(TRAP, "trap"), (NOTIFY, "notify")]
